@@ -5,12 +5,12 @@
 #' patterns like `"r_"` or `"b[]"` (mostly applicable to Stan models)
 #' and adding columns with information to which group or component parameters
 #' belong (i.e. fixed or random, count or zero-inflated...)
-#' \cr \cr
+#'
 #' The main purpose of this function is to easily filter and select model parameters,
 #' in particular of - but not limited to - posterior samples from Stan models,
 #' depending on certain characteristics. This might be useful when only selective
 #' results should be reported or results from all parameters should be filtered
-#' to return only certain results (see [print_parameters()]).
+#' to return only certain results (see [`print_parameters()`]).
 #'
 #' @param x A fitted model.
 #' @inheritParams find_parameters
@@ -27,17 +27,16 @@
 #' The `Effects` column indicate if a parameter is a *fixed* or *random* effect.
 #' The `Component` can either be *conditional* or *zero_inflated*. For models
 #' with random effects, the `Group` column indicates the grouping factor of the
-#' random effects. For multivariate response models from \pkg{brms} or
-#' \pkg{rstanarm}, an additional *Response* column is included, to indicate
+#' random effects. For multivariate response models from **brms** or
+#' **rstanarm**, an additional *Response* column is included, to indicate
 #' which parameters belong to which response formula. Furthermore,
 #' *Cleaned_Parameter* column is returned that contains "human readable"
 #' parameter names (which are mostly identical to `Parameter`, except for for
-#' models from \pkg{brms} or \pkg{rstanarm}, or for specific terms like smooth-
+#' models from **brms** or **rstanarm**, or for specific terms like smooth-
 #' or spline-terms).
 #'
-#' @examples
-#' \dontrun{
-#' library(brms)
+#' @examplesIf require("curl", quietly = TRUE) && curl::has_internet() && require("brms")
+#' \donttest{
 #' model <- download_model("brms_zi_2")
 #' clean_parameters(model)
 #' }
@@ -142,6 +141,7 @@ clean_parameters.emmGrid <- function(x, ...) {
 
   out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(out)
+  class(out) <- c("clean_parameters", class(out))
   out
 }
 
@@ -267,7 +267,9 @@ clean_parameters.glmm <- function(x, ...) {
   })
 
   out <- text_remove_backticks(do.call(rbind, l))
-  .remove_empty_columns_from_pars(out)
+  out <- .remove_empty_columns_from_pars(out)
+  class(out) <- c("clean_parameters", class(out))
+  out
 }
 
 
@@ -279,7 +281,7 @@ clean_parameters.MCMCglmm <- clean_parameters.glmm
 clean_parameters.lavaan <- function(x, ...) {
   params <- get_parameters(x)
 
-  data.frame(
+  out <- data.frame(
     Parameter = params$Parameter,
     Component = params$Component,
     Group = "",
@@ -288,6 +290,8 @@ clean_parameters.lavaan <- function(x, ...) {
     stringsAsFactors = FALSE,
     row.names = NULL
   )
+  class(out) <- c("clean_parameters", class(out))
+  out
 }
 
 
@@ -299,6 +303,7 @@ clean_parameters.blavaan <- function(x, ...) {
   params$Group <- ""
   params$Function <- ""
   params$Cleaned_Parameter <- params$Parameter
+  class(params) <- c("clean_parameters", class(params))
   params
 }
 
@@ -387,10 +392,10 @@ clean_parameters.aovlist <- function(x, ...) {
 
 #' @export
 clean_parameters.afex_aov <- function(x, ...) {
-  if (!is.null(x$aov)) {
-    clean_parameters(x$aov, ...)
-  } else {
+  if (is.null(x$aov)) {
     clean_parameters(x$lm, ...)
+  } else {
+    clean_parameters(x$aov, ...)
   }
 }
 
@@ -547,9 +552,7 @@ clean_parameters.mlm <- function(x, ...) {
     # for backwards compatibility, we keep the old behaviour. But generally,
     # when we have the argument "version = 2", Stan models have the same
     # labelling as frequentist models
-    if (!identical(dots$version, 2)) {
-      r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\3: \\1", out$Cleaned_Parameter[rand_eff])
-    } else {
+    if (identical(dots$version, 2)) {
       out$Level <- ""
       r_levels <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\2", out$Cleaned_Parameter[rand_eff])
       r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\1", out$Cleaned_Parameter[rand_eff])
@@ -562,6 +565,8 @@ clean_parameters.mlm <- function(x, ...) {
       if (any(sd_cor)) {
         out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
       }
+    } else {
+      r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\3: \\1", out$Cleaned_Parameter[rand_eff])
     }
     r_pars <- gsub("__zi", "", r_pars, fixed = TRUE)
     r_grps <- gsub("__zi", "", r_grps, fixed = TRUE)
@@ -584,11 +589,11 @@ clean_parameters.mlm <- function(x, ...) {
     out$Component[simplex] <- "simplex"
   }
 
-  smooth <- startsWith(out$Cleaned_Parameter, "sds_")
-  if (length(smooth)) {
+  smooth_parameters <- startsWith(out$Cleaned_Parameter, "sds_")
+  if (length(smooth_parameters)) {
     out$Cleaned_Parameter <- gsub("^sds_", "", out$Cleaned_Parameter)
-    out$Component[smooth] <- "smooth_sd"
-    out$Function[smooth] <- "smooth"
+    out$Component[smooth_parameters] <- "smooth_sd"
+    out$Function[smooth_parameters] <- "smooth"
   }
 
   # fix intercept names
@@ -599,7 +604,7 @@ clean_parameters.mlm <- function(x, ...) {
     out$Cleaned_Parameter[intercepts] <- "(Intercept)"
   }
 
-  interaction_terms <- which(grepl(".", out$Cleaned_Parameter, fixed = TRUE))
+  interaction_terms <- grep(".", out$Cleaned_Parameter, fixed = TRUE)
 
   if (length(interaction_terms)) {
     for (i in interaction_terms) {
@@ -657,11 +662,7 @@ clean_parameters.mlm <- function(x, ...) {
 
   if (any(rand_effects)) {
     r_pars <- gsub("b\\[(.*) (.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
-    if (!identical(dots$version, 2)) {
-      re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
-      r_grps <- gsub("b\\[(.*) (.*)\\]", "\\1", out$Cleaned_Parameter[rand_effects])
-      out$Group[rand_effects] <- sprintf("%s: %s", r_grps, re_grp_level)
-    } else {
+    if (identical(dots$version, 2)) {
       out$Level <- ""
       r_levels <- gsub("b\\[(.*) (.*):(.*)\\]", "\\3", out$Cleaned_Parameter[rand_effects])
       r_grps <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
@@ -672,6 +673,10 @@ clean_parameters.mlm <- function(x, ...) {
       if (any(sd_cor)) {
         out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
       }
+    } else {
+      re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
+      r_grps <- gsub("b\\[(.*) (.*)\\]", "\\1", out$Cleaned_Parameter[rand_effects])
+      out$Group[rand_effects] <- sprintf("%s: %s", r_grps, re_grp_level)
     }
 
     out$Cleaned_Parameter[rand_effects] <- r_pars
@@ -679,12 +684,12 @@ clean_parameters.mlm <- function(x, ...) {
 
   # clean remaining parameters
 
-  smooth <- startsWith(out$Cleaned_Parameter, "smooth_sd[")
+  smooth_parameters <- startsWith(out$Cleaned_Parameter, "smooth_sd[")
 
-  if (length(smooth)) {
+  if (length(smooth_parameters)) {
     out$Cleaned_Parameter <- gsub("^smooth_sd\\[(.*)\\]", "\\1", out$Cleaned_Parameter)
-    out$Component[smooth] <- "smooth_sd"
-    out$Function[smooth] <- "smooth"
+    out$Component[smooth_parameters] <- "smooth_sd"
+    out$Function[smooth_parameters] <- "smooth"
   }
 
   out
@@ -693,32 +698,30 @@ clean_parameters.mlm <- function(x, ...) {
 
 
 .clean_bfbayesfactor_params <- function(out) {
-  pars <- do.call(rbind, strsplit(out$Parameter, "-", TRUE))
+  pars <- do.call(rbind, strsplit(out$Parameter, "-", fixed = TRUE))
 
   if (ncol(pars) == 1) {
     return(out)
   }
 
   out$Cleaned_Parameter <- tryCatch(
-    {
-      apply(pars, 1, function(i) {
-        if (i[1] == i[2]) {
-          i[2] <- ""
-        } else if (i[1] != i[2] && !grepl(":", i[1], fixed = TRUE)) {
-          i[1] <- paste0(i[1], " [", i[2], "]")
-          i[2] <- ""
-        } else if (grepl(":", i[1], fixed = TRUE)) {
-          f <- unlist(strsplit(i[1], ":", fixed = TRUE))
-          l <- unlist(strsplit(i[2], ".&.", fixed = TRUE))
-          m <- match(f, l)
-          matches <- m[!is.na(m)]
-          l[matches] <- ""
-          l[-matches] <- paste0("[", l[-matches], "]")
-          i[1] <- paste0(f, l, collapse = " * ")
-        }
-        as.vector(i[1])
-      })
-    },
+    apply(pars, 1, function(i) {
+      if (i[1] == i[2]) {
+        i[2] <- ""
+      } else if (i[1] != i[2] && !grepl(":", i[1], fixed = TRUE)) {
+        i[1] <- paste0(i[1], " [", i[2], "]")
+        i[2] <- ""
+      } else if (grepl(":", i[1], fixed = TRUE)) {
+        f <- unlist(strsplit(i[1], ":", fixed = TRUE), use.names = FALSE)
+        l <- unlist(strsplit(i[2], ".&.", fixed = TRUE), use.names = FALSE)
+        m <- match(f, l)
+        matches <- m[!is.na(m)]
+        l[matches] <- ""
+        l[-matches] <- paste0("[", l[-matches], "]")
+        i[1] <- paste0(f, l, collapse = " * ")
+      }
+      as.vector(i[1])
+    }),
     error = function(e) {
       out$Cleaned_Parameter
     }
