@@ -96,7 +96,7 @@ find_statistic <- function(x, ...) {
     "ivreg", "ivFixed", "iv_robust", "ivprobit",
     "lm", "lm_robust", "lm.beta", "lme", "lmerMod", "lmerModLmerTest",
     "lmodel2", "lmRob", "lmrob", "lqm", "lqmm",
-    "maxLik", "mixed", "mhurdle", "mlm", "multinom", "mmrm", "mmrm_fit",
+    "maxLik", "mixed", "mhurdle", "mlm", "mmrm", "mmrm_fit",
     "mmrm_tmb",
     "nlmerMod", "nlrq", "nls",
     "ols", "orcutt",
@@ -120,13 +120,13 @@ find_statistic <- function(x, ...) {
     "deltaMethod", "DirichletRegModel",
     "ergm",
     "feglm", "flexsurvreg",
-    "gee", "glimML", "glmm", "glmmadmb", "glmmFit", "glmmLasso", "glmmTMB",
-    "glmx", "gmnl",
+    "gee", "ggcomparisons", "glimML", "glmm", "glmmadmb", "glmmFit", "glmmLasso",
+    "glmmTMB", "glmx", "gmnl",
     "hurdle",
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "logitr", "LORgee", "lrm",
     "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
     "MixMod", "mjoint", "mle", "mle2", "mlogit", "mblogit", "mclogit", "mmclogit",
-    "mvmeta", "mvord",
+    "multinom", "mvmeta", "mvord",
     "negbin", "negbinmfx", "negbinirr", "nlreg", "nestedLogit",
     "objectiveML", "orm",
     "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm", "phyloglm",
@@ -174,7 +174,6 @@ find_statistic <- function(x, ...) {
       "bam", "bigglm",
       "cgam", "cgamm",
       "eglm", "emmGrid", "emm_list",
-      "fixest",
       "gam", "glm", "Glm", "glmc", "glmerMod", "glmRob", "glmrob",
       "pseudoglm",
       "scam",
@@ -191,7 +190,7 @@ find_statistic <- function(x, ...) {
 
   # pattern finding ----------------------------------------------------------
 
-  unclear.mods <- "plm"
+  unclear.mods <- c("plm", "fixest")
 
   if (inherits(x, "glht")) {
     if (x$df == 0) {
@@ -290,6 +289,17 @@ find_statistic <- function(x, ...) {
   # ambiguous cases -----------------------------------------------------------
 
   if (model_class %in% unclear.mods) {
+    # special handling for fixest, see
+    # https://github.com/easystats/parameters/issues/892#issuecomment-1712645841
+    # and https://github.com/lrberge/fixest/blob/c14c55917897478d996f80bd3392d2e7355b1f29/R/ESTIMATION_FUNS.R#L2903
+    if (model_class == "fixest") {
+      if (m_info$family %in% c("binomial", "poisson")) {
+        return("z-statistic")
+      } else {
+        return("t-statistic")
+      }
+    }
+
     col_names <- colnames(as.data.frame(summary(x)$coefficients))
 
     t_names <- c(
