@@ -155,11 +155,11 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
   }
 
   if (!is.null(dof) && length(dof) > 0 && all(dof == 0) && isTRUE(verbose)) {
-    warning("Model has zero degrees of freedom!", call. = FALSE)
+    format_warning("Model has zero degrees of freedom!")
   }
 
   if (is.null(dof) && isTRUE(verbose)) {
-    warning("Could not extract degrees of freedom.", call. = FALSE)
+    format_warning("Could not extract degrees of freedom.")
   }
 
   dof
@@ -205,13 +205,13 @@ get_df.emm_list <- function(x, ...) {
     return(.boot_em_df(x))
   }
   s <- summary(x)
-  unname(unlist(lapply(s, function(i) {
+  unlist(lapply(s, function(i) {
     if (is.null(i$df)) {
       rep(Inf, nrow(i))
     } else {
       i$df
     }
-  })))
+  }), use.names = FALSE)
 }
 
 
@@ -221,6 +221,22 @@ get_df.coeftest <- function(x, ...) {
 }
 
 
+#' @export
+get_df.phylolm <- function(x, type = "residual", ...) {
+  type <- match.arg(
+    tolower(type),
+    choices = c("wald", "residual", "normal", "model")
+  )
+  type <- switch(type,
+    model = stats::logLik(x)$df,
+    get_df.default(x, type = "residual")
+  )
+}
+
+#' @export
+get_df.phyloglm <- get_df.phylolm
+
+
 #' @export
 get_df.fixest <- function(x, type = "residual", ...) {
   # fixest degrees of freedom can be tricky. best to use the function by the
@@ -234,8 +250,8 @@ get_df.fixest <- function(x, type = "residual", ...) {
     choices = c("wald", "residual", "normal")
   )
   type <- switch(type,
-    "wald" = "t",
-    "residual" = "resid",
+    wald = "t",
+    residual = "resid",
     type
   )
   if (type == "normal") {
@@ -372,13 +388,17 @@ get_df.mediate <- function(x, ...) {
 # Model approach (model-based / logLik df) ------------------------------
 
 .model_df <- function(x) {
-  dof <- tryCatch(attr(stats::logLik(x), "df"), error = function(e) NULL)
+  # logLik() for plm calls get_df(), so we would have a recursion here.
+  # therefore, we need to check for plm first
+  if (inherits(x, "plm")) {
+    dof <- NULL
+  } else {
+    dof <- .safe(attr(stats::logLik(x), "df"))
+  }
 
   if (is.null(dof) || all(is.infinite(dof)) || all(is.na(dof))) {
-    r <- tryCatch(x$rank, error = function(e) NULL)
-    if (!is.null(r)) {
-      dof <- r + 1
-    } else {
+    r <- .safe(x$rank)
+    if (is.null(r)) {
       n <- n_parameters(x)
       extra <- 0
       mi <- model_info(x, verbose = FALSE)
@@ -388,6 +408,8 @@ get_df.mediate <- function(x, ...) {
       }
 
       dof <- n + extra
+    } else {
+      dof <- r + 1
     }
   }
 
