@@ -31,8 +31,8 @@
 #' `effects` and `component` can be used.
 #'
 #' @section BFBayesFactor Models:
-#' Note that for `BFBayesFactor` models (from the \pkg{BayesFactor}
-#' package), posteriors are only extracted from the first numerator model (i.e.,
+#' Note that for `BFBayesFactor` models (from the **BayesFactor** package),
+#' posteriors are only extracted from the first numerator model (i.e.,
 #' `model[1]`). If you want to apply some function `foo()` to another
 #' model stored in the `BFBayesFactor` object, index it directly, e.g.
 #' `foo(model[2])`, `foo(1/model[5])`, etc.
@@ -58,9 +58,9 @@ get_parameters.BGGM <- function(x,
 
   component <- match.arg(component)
   out <- switch(component,
-    "conditional" = out[, conditional, drop = FALSE],
-    "correlation" = out[, correlations, drop = FALSE],
-    "intercept" = out[, intercepts, drop = FALSE],
+    conditional = out[, conditional, drop = FALSE],
+    correlation = out[, correlations, drop = FALSE],
+    intercept = out[, intercepts, drop = FALSE],
     out
   )
   if (isTRUE(summary)) {
@@ -140,11 +140,11 @@ get_parameters.BFBayesFactor <- function(x,
       ))
 
     out <- switch(bf_type,
-      "correlation" = data.frame("rho" = as.numeric(posteriors$rho)),
-      "ttest1" = data.frame("Difference" = as.numeric(posteriors[, 1]) - x@numerator[[1]]@prior$mu),
-      "ttest2" = data.frame("Difference" = as.numeric(posteriors[, 2]) - x@numerator[[1]]@prior$mu),
-      "meta" = data.frame("Effect" = as.numeric(posteriors$delta)),
-      "linear" = .get_bf_posteriors(posteriors, params),
+      correlation = data.frame(rho = as.numeric(posteriors$rho)),
+      ttest1 = data.frame(Difference = as.numeric(posteriors[, 1]) - x@numerator[[1]]@prior$mu),
+      ttest2 = data.frame(Difference = as.numeric(posteriors[, 2]) - x@numerator[[1]]@prior$mu),
+      meta = data.frame(Effect = as.numeric(posteriors$delta)),
+      linear = .get_bf_posteriors(posteriors, params),
       NULL
     )
   } else if (bf_type == "proptest") {
@@ -202,7 +202,7 @@ get_parameters.stanmvreg <- function(x,
     parms[[i]]$sigma <- NULL
   }
 
-  out <- as.data.frame(x)[unlist(lapply(compact_list(parms), function(i) i[elements]))]
+  out <- as.data.frame(x)[unlist(lapply(compact_list(parms), function(i) i[elements]), use.names = FALSE)]
 
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
@@ -222,12 +222,12 @@ get_parameters.brmsfit <- function(x,
                                    centrality = "mean",
                                    ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", .all_elements()))
+  component <- match.arg(component, choices = c("all", .all_elements(), "location", "distributional"))
 
   if (is_multivariate(x)) {
     parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
     elements <- .get_elements(effects, component)
-    out <- as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]))]
+    out <- as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]), use.names = FALSE)]
   } else {
     out <- as.data.frame(x)[.get_parms_data(x, effects, component, parameters)]
   }
@@ -307,9 +307,9 @@ get_parameters.bayesx <- function(x,
   )
 
   params <- switch(component,
-    "all" = rbind(fixed_dat, smooth_dat),
-    "conditional" = fixed_dat,
-    "smooth_terms" = smooth_dat
+    all = rbind(fixed_dat, smooth_dat),
+    conditional = fixed_dat,
+    smooth_terms = smooth_dat
   )
 
   out <- text_remove_backticks(params)
@@ -352,7 +352,7 @@ get_parameters.bamlss <- function(x,
   elements <- .get_elements(effects = "all", component)
 
   parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
-  out <- as.data.frame(unclass(x$samples))[unname(unlist(parms[elements]))]
+  out <- as.data.frame(unclass(x$samples))[unlist(parms[elements], use.names = FALSE)]
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
   }
@@ -458,8 +458,8 @@ get_parameters.sim <- function(x,
 
 .summary_of_posteriors <- function(out, centrality = "mean", ...) {
   s <- switch(centrality,
-    "mean" = vapply(out, mean, numeric(1), na.rm = TRUE),
-    "median" = vapply(out, stats::median, numeric(1), na.rm = TRUE),
+    mean = vapply(out, mean, numeric(1), na.rm = TRUE),
+    median = vapply(out, stats::median, numeric(1), na.rm = TRUE),
     vapply(out, mean, numeric(1), na.rm = TRUE)
   )
   data.frame(
@@ -546,7 +546,7 @@ get_parameters.sim <- function(x,
     }
   } else if (methods::is(object, "var_estimate")) {
     if (!methods::is(object, "default")) {
-      stop("Object must be from 'var_estimate'.", call. = FALSE)
+      format_error("Object must be from 'var_estimate'.")
     }
     p <- object$p
     pcors_total <- p * (p - 1) * 0.5
@@ -586,7 +586,7 @@ get_parameters.sim <- function(x,
     }
     posterior_samples <- cbind(posterior_samples, beta_start)
   } else {
-    stop("Object class not currently supported.", call. = FALSE)
+    format_error("Object class not currently supported.")
   }
 
   posterior_samples
