@@ -11,12 +11,15 @@
 #' "predictions" (a lose term for a variety of things) is a non-trivial process,
 #' with lots of caveats and complications. Read the 'Details' section for more
 #' information.
-#' \cr \cr
-#' `get_predicted_ci()` returns the confidence (or prediction) interval (CI)
+#'
+#' [`get_predicted_ci()`] returns the confidence (or prediction) interval (CI)
 #' associated with predictions made by a model. This function can be called
 #' separately on a vector of predicted values. `get_predicted()` usually
 #' returns confidence intervals (included as attribute, and accessible via the
-#' `as.data.frame()` method) by default.
+#' `as.data.frame()` method) by default. It is preferred to rely on the
+#' `get_predicted()` function for standard errors and confidence intervals -
+#' use `get_predicted_ci()` only if standard errors and confidence intervals
+#' are not available otherwise.
 #'
 #' @param x A statistical model (can also be a data.frame, in which case the
 #'   second argument has to be a model).
@@ -105,9 +108,8 @@
 #' In `insight::get_predicted()`, the `predict` argument jointly
 #' modulates two separate concepts, the **scale** and the **uncertainty interval**.
 #'
-#' \subsection{Confidence Interval (CI) vs. Prediction Interval (PI))}{
-#' \itemize{
-#'   \item **Linear models** - `lm()`: For linear models, Prediction
+#' @section Confidence Interval (CI) vs. Prediction Interval (PI)):
+#' - **Linear models** - `lm()`: For linear models, prediction
 #'   intervals (`predict="prediction"`) show the range that likely
 #'   contains the value of a new observation (in what range it is likely to
 #'   fall), whereas confidence intervals (`predict="expectation"` or
@@ -119,13 +121,12 @@
 #'   Moreover, prediction intervals will not necessarily become narrower as the
 #'   sample size increases (as they do not reflect only the quality of the fit,
 #'   but also the variability within the data).
-#'   \item **Generalized Linear models** - `glm()`: For binomial models,
+#' - **Generalized Linear models** - `glm()`: For binomial models,
 #'   prediction intervals are somewhat useless (for instance, for a binomial
 #'   (Bernoulli) model for which the dependent variable is a vector of 1s and
 #'   0s, the prediction interval is... `[0, 1]`).
-#' }}
 #'
-#' \subsection{Link scale vs. Response scale}{
+#' @section Link scale vs. Response scale:
 #' When users set the `predict` argument to `"expectation"`, the predictions
 #' are returned on the response scale, which is arguably the most convenient
 #' way to understand and visualize relationships of interest. When users set
@@ -138,17 +139,15 @@
 #' function will first calculate predictions as if the user had selected
 #' `predict="expectation"`. Then, it will round the responses in order to
 #' return the most likely outcome.
-#' }
 #'
-#' \subsection{Heteroscedasticity consistent standard errors}{
+#' @section Heteroscedasticity consistent standard errors:
 #' The arguments `vcov` and `vcov_args` can be used to calculate robust
 #' standard errors for confidence intervals of predictions. These arguments,
 #' when provided in `get_predicted()`, are passed down to `get_predicted_ci()`,
 #' thus, see the related documentation there for more
 #' details.
-#' }
 #'
-#' \subsection{Bayesian and Bootstrapped models and iterations}{
+#' @section Bayesian and Bootstrapped models and iterations:
 #' For predictions based on multiple iterations, for instance in the case of Bayesian
 #' models and bootstrapped predictions, the function used to compute the centrality
 #' (point-estimate predictions) can be modified via the `centrality_function`
@@ -156,11 +155,10 @@
 #' The default is `mean`. Individual draws can be accessed by running
 #' `iter <- as.data.frame(get_predicted(model))`, and their iterations can be
 #' reshaped into a long format by `bayestestR::reshape_iterations(iter)`.
-#' }
 #'
 #' @seealso [get_datagrid()]
 #'
-#' @examples
+#' @examplesIf require("boot")
 #' data(mtcars)
 #' x <- lm(mpg ~ cyl + hp, data = mtcars)
 #'
@@ -173,12 +171,10 @@
 #' # Get CI
 #' as.data.frame(predictions)
 #'
-#' if (require("boot")) {
-#'   # Bootstrapped
-#'   as.data.frame(get_predicted(x, iterations = 4))
-#'   # Same as as.data.frame(..., keep_iterations = FALSE)
-#'   summary(get_predicted(x, iterations = 4))
-#' }
+#' # Bootstrapped
+#' as.data.frame(get_predicted(x, iterations = 4))
+#' # Same as as.data.frame(..., keep_iterations = FALSE)
+#' summary(get_predicted(x, iterations = 4))
 #'
 #' # Different prediction types ------------------------
 #' data(iris)
@@ -235,19 +231,18 @@ get_predicted.default <- function(x,
 
   # 1. step: predictions
   predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
-  predictions <- tryCatch(do.call("predict", predict_args), error = function(e) NULL)
+  predictions <- .safe(do.call("predict", predict_args))
 
   # may fail due to invalid "dot_args", so try shorter argument list
   if (is.null(predictions)) {
-    predictions <- tryCatch(
-      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type))),
-      error = function(e) NULL
+    predictions <- .safe(
+      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
     )
   }
 
   # still fails? try fitted()
   if (is.null(predictions)) {
-    predictions <- tryCatch(do.call("fitted", predict_args), error = function(e) NULL)
+    predictions <- .safe(do.call("fitted", predict_args))
   }
 
   # stop here if we have no predictions
@@ -258,29 +253,24 @@ get_predicted.default <- function(x,
   }
 
   # 2. step: confidence intervals
-  ci_data <- tryCatch(
-    {
-      get_predicted_ci(
-        x,
-        predictions,
-        data = args$data,
-        ci_type = args$ci_type,
-        ci_method = ci_method,
-        vcov = vcov,
-        vcov_args = vcov_args,
-        ...
-      )
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  ci_data <- .safe({
+    get_predicted_ci(
+      x,
+      predictions,
+      data = args$data,
+      ci_type = args$ci_type,
+      ci_method = ci_method,
+      vcov = vcov,
+      vcov_args = vcov_args,
+      ...
+    )
+  })
 
   # 3. step: back-transform
-  if (!is.null(predictions)) {
-    out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
-  } else {
+  if (is.null(predictions)) {
     out <- NULL
+  } else {
+    out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
   }
 
   # 4. step: final preparation
@@ -295,7 +285,7 @@ get_predicted.default <- function(x,
 get_predicted.data.frame <- function(x, data = NULL, verbose = TRUE, ...) {
   # This makes it pipe friendly; data %>% get_predicted(model)
   if (is.null(data)) {
-    stop("Please provide a model to base the estimations on.", call. = FALSE)
+    format_error("Please provide a model to base the estimations on.")
   } else {
     get_predicted(data, x, verbose = verbose, ...)
   }
@@ -323,14 +313,16 @@ get_predicted.lm <- function(x,
     )
   }
 
-  # 0. step: convert matrix variable types attributes to numeric, if necessary
-  dataClasses <- attributes(x[["terms"]])$dataClasses
+  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+
+  # 0. step: convert matrix variable types attributes to numeric, if necessary.
   # see https://github.com/easystats/insight/pull/671
+  dataClasses <- attributes(x[["terms"]])$dataClasses
   if ("nmatrix.1" %in% dataClasses) {
     dataClasses[dataClasses == "nmatrix.1"] <- "numeric"
     attributes(x$terms)$dataClasses <- dataClasses
     attributes(attributes(x$model)$terms)$dataClasses <- dataClasses
-    x$model[] <- lapply(x$model, function(x) {
+    args$data[] <- lapply(args$data, function(x) {
       if (all(class(x) == c("matrix", "array"))) { # nolint
         as.numeric(x)
       } else {
@@ -339,8 +331,6 @@ get_predicted.lm <- function(x,
     })
   }
 
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
-
   # 1. step: predictions
   if (is.null(iterations)) {
     predictions <- predict_function(x, data = args$data)
@@ -483,10 +473,101 @@ get_predicted.bife <- function(x,
     ...
   )
 
-  out <- tryCatch(stats::predict(x, type = args$scale, X_new = args$data), error = function(e) NULL)
+  out <- .safe(stats::predict(x, type = args$scale, X_new = args$data))
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list("data" = data))
+    out <- .get_predicted_out(out, args = list(data = data))
+  }
+
+  out
+}
+
+
+# rma -------------------------------------------------------------------
+# =======================================================================
+#' @export
+get_predicted.rma <- function(x,
+                              predict = "expectation",
+                              data = NULL,
+                              ci = NULL,
+                              verbose = TRUE,
+                              transf = NULL,
+                              transf_args = NULL,
+                              ...) {
+  args <- .get_predicted_args(x,
+    data = data,
+    predict = predict,
+    verbose = TRUE,
+    ...
+  )
+
+  has_scale_model <- inherits(x, "rma.ls")
+  # TODO: Handle tau2.levels and gamma2.levels arguments for rma.mv()
+
+  # metafor requires data for predict to be a model matrix (with no intercept)
+  if (!is.null(data)) {
+    newmods <- .create_newmods_rma(x, data)
+    if (has_scale_model) {
+      newscale <- .create_newscale_rma(x, data)
+    }
+  }
+
+  if (predict %in% c("link", "expectation", "prediction")) {
+    if (!is.null(data)) {
+      out <- .safe(stats::predict(x, transf = transf, targs = transf_args))
+    } else if (has_scale_model) {
+      out <- .safe(stats::predict(x, newmods = newmods, newscale = newscale, transf = transf, targs = transf_args))
+    } else {
+      out <- .safe(stats::predict(x, newmods = newmods, transf = transf, targs = transf_args))
+    }
+    if (predict == "prediction") {
+      out <- stats::setNames(
+        as.data.frame(out)[, c("pred", "se", "pi.lb", "pi.ub")],
+        c("Predicted", "SE", "CI_low", "CI_high")
+      )
+    } else {
+      out <- stats::setNames(
+        as.data.frame(out)[, c("pred", "se", "ci.lb", "ci.ub")],
+        c("Predicted", "SE", "CI_low", "CI_high")
+      )
+    }
+  } else if (predict == "blup") {
+    if (!is.null(data)) {
+      check_if_installed("metafor")
+      out <- .safe(metafor::blup(x, transf = transf, targs = transf_args))
+    } else if (has_scale_model) {
+      # TODO: Remove this helper function if metafor adds support for newmods/newscale in metafor::blup()
+      out <- .safe(
+        .get_blup_rma(
+          x,
+          ci = ci,
+          newmods = newmods,
+          newscale = newscale,
+          transf = transf,
+          targs = transf_args
+        )
+      )
+    } else {
+      # TODO: Remove this helper function if metafor adds support for newmods in metafor::blup()
+      out <- .safe(.get_blup_rma(
+        x,
+        ci = ci,
+        newmods = newmods,
+        transf = transf,
+        targs = transf_args
+      ))
+    }
+    out <- stats::setNames(as.data.frame(out), c("Predicted", "SE", "CI_low", "CI_high"))
+  } else {
+    format_error("`predict` must be one of 'link', 'expectation', 'prediction', or 'blup'.")
+  }
+
+  if (!is.null(out)) {
+    # Handle single-row output from intercept-only models
+    if (nrow(out) == 1) {
+      out <- do.call(rbind, lapply(seq_along(x$slab), function(i) out))
+    }
+    out <- .get_predicted_out(out, args = list(data = data))
   }
 
   out
@@ -503,17 +584,17 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
   if (is.null(data)) {
     args <- c(list(x), list(...))
   } else {
-    args <- c(list(x, "newdata" = data), list(...))
+    args <- c(list(x, newdata = data), list(...))
   }
 
-  out <- tryCatch(do.call("predict", args), error = function(e) NULL)
+  out <- .safe(do.call("predict", args))
 
   if (is.null(out)) {
-    out <- tryCatch(do.call("fitted", args), error = function(e) NULL)
+    out <- .safe(do.call("fitted", args))
   }
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list("data" = data))
+    out <- .get_predicted_out(out, args = list(data = data))
   }
 
   out
@@ -522,6 +603,56 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
 
 
 
+# phylolm ---------------------------------------------------------------
+# =======================================================================
+
+#' @export
+get_predicted.phylolm <- function(x,
+                                  data = NULL,
+                                  predict = "expectation",
+                                  verbose = TRUE,
+                                  ...) {
+  # evaluate arguments
+  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+
+  # evaluate dots, remove some arguments that might be duplicated else
+  dot_args <- list(...)
+  dot_args[["newdata"]] <- NULL
+  dot_args[["type"]] <- NULL
+
+
+  # 1. step: predictions
+  predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
+  predictions <- .safe(do.call("predict", predict_args))
+
+  # may fail due to invalid "dot_args", so try shorter argument list
+  if (is.null(predictions)) {
+    predictions <- .safe(
+      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
+    )
+  }
+
+  # stop here if we have no predictions
+  if (is.null(predictions) && isTRUE(verbose)) {
+    format_warning(
+      paste0("Could not compute predictions for model of class `", class(x)[1], "`.")
+    )
+  }
+
+  # sometimes, a mtrix is returned
+  if (is.matrix(predictions)) {
+    predictions <- predictions[, 1]
+  }
+  # 2. step: final preparation
+  if (!is.null(out)) {
+    out <- .get_predicted_out(predictions, args = args, ci_data = NULL)
+  }
+
+  out
+}
+
+
+
 # ====================================================================
 # Utils --------------------------------------------------------------
 # ====================================================================
@@ -586,15 +717,15 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
 
       # Transform SE (https://github.com/SurajGupta/r-source/blob/master/src/library/stats/R/predict.glm.R#L60)
       # Delta method; SE * deriv( inverse_link(x) wrt lin_pred(x) )
-      mu_eta <- tryCatch(abs(get_family(x)$mu.eta(predictions)), error = function(e) NULL)
+      mu_eta <- .safe(abs(get_family(x)$mu.eta(predictions)))
       if (is.null(mu_eta)) {
         ci_data[se_col] <- NULL
         if (isTRUE(verbose)) {
-          warning(format_message(
+          format_warning(
             "Could not apply Delta method to transform standard errors.",
             "You may be able to obtain standard errors by using the ",
             "`predict=\"link\"` argument value."
-          ), call. = FALSE)
+          )
         }
       } else {
         ci_data[se_col] <- ci_data[se_col] * mu_eta
@@ -606,7 +737,7 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
 
     # Transform iterations
     if ("iterations" %in% names(attributes(predictions))) {
-      attr(predictions, "iterations") <- as.data.frame(sapply(attributes(predictions)$iterations, link_inv))
+      attr(predictions, "iterations") <- as.data.frame(sapply(attributes(predictions)$iterations, link_inv)) # nolint
     }
 
     # Transform to response "type"
@@ -616,7 +747,7 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
       predictions <- .get_predict_transform_response(predictions, response = response)
       if ("iterations" %in% names(attributes(predictions))) {
         attr(predictions, "iterations") <- as.data.frame(
-          sapply(
+          sapply( # nolint
             attributes(predictions)$iterations,
             .get_predict_transform_response,
             response = response
@@ -645,16 +776,14 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
   }
 
   # multidimensional or "grouped" predictions (e.g., nnet::multinom with `predict(type="probs")`)
-  if (is.matrix(predictions) && ncol(predictions) > 1) {
+  if (is.matrix(predictions) && ncol(predictions) > 1L) {
     predictions <- as.data.frame(predictions)
     vary <- colnames(predictions)
     predictions$Row <- seq_len(nrow(predictions))
     # if we have any focal predictors, add those as well, so we have
     # the associated levels/values for "Row"
     if (!is.null(args$data)) {
-      focal_predictors <- tryCatch(names(which(n_unique(args$data) > 1)),
-        error = function(e) NULL
-      )
+      focal_predictors <- .safe(names(which(n_unique(args$data) > 1L)))
       if (!is.null(focal_predictors)) {
         predictions <- cbind(predictions, args$data[focal_predictors])
       }
@@ -756,3 +885,23 @@ get_predicted.afex_aov <- function(x, data = NULL, ...) {
   attr(predictions, "iterations") <- iter
   predictions
 }
+
+
+
+# -------------------------------------------------------------------------
+
+.create_newmods_rma <- function(x, data, ...) {
+
+}
+
+.create_newscale_rma <- function(x, data, ...) {
+
+}
+
+.get_blup_rma <- function(x, data, ci = NULL, ...) {
+  if (is.element(x$test, c("knha", "adhoc", "t"))) {
+    crit <- stats::qt(ci / 2, df = x$ddf, lower.tail = FALSE)
+  } else {
+    crit <- stats::qnorm(ci / 2, lower.tail = FALSE)
+  }
+}
