@@ -1,4 +1,4 @@
-#' @title Checks if a regression model object is supported in \pkg{insight} package
+#' @title Checks if a regression model object is supported by the insight package
 #' @name is_model_supported
 #'
 #' @description Small helper that checks if a model is a *supported*
@@ -73,7 +73,7 @@ supported_models <- function() {
     "glmrob", "glmRob", "glmx", "gls", "gmnl",
 
     # h ----------------------------
-    "HLfit", "htest", "hurdle",
+    "HLfit", "htest", "hurdle", "hglm",
 
     # i ----------------------------
     "ivFixed", "iv_robust", "ivreg", "ivprobit",
@@ -92,14 +92,14 @@ supported_models <- function() {
     "multinom", "mvord", "mmclogit", "mmrm", "mmrm_fit", "mmrm_tmb",
 
     # n ----------------------------
-    "negbinmfx", "negbinirr",
+    "negbinmfx", "negbinirr", "nestedLogit",
 
     # o ----------------------------
     "ols", "onesampb", "orm",
 
     # p ----------------------------
     "PMCMR", "poissonmfx", "poissonirr", "pgmm", "plm", "polr", "psm",
-    "probitmfx",
+    "probitmfx", "phyloglm", "phylolm",
 
     # r ----------------------------
     "Rchoice", "ridgelm", "riskRegression", "rjags", "rlm", "rlmerMod",
