@@ -21,6 +21,7 @@
 #' * `is_count`: model is a count model (i.e. family is either poisson or negative binomial)
 #' * `is_beta`: family is beta
 #' * `is_betabinomial`: family is beta-binomial
+#' * `is_orderedbeta`: family is ordered beta
 #' * `is_dirichlet`: family is dirichlet
 #' * `is_exponential`: family is exponential (e.g. Gamma or Weibull)
 #' * `is_logit`: model has logit link
@@ -38,23 +39,28 @@
 #' * `is_hurdle`: model has zero-inflation component and is a hurdle-model (truncated family distribution)
 #' * `is_dispersion`: model has dispersion component (not only dispersion _parameter_)
 #' * `is_mixed`: model is a mixed effects model (with random effects)
-#' * `is_multivariate`: model is a multivariate response model (currently only works for _brmsfit_ objects)
+#' * `is_multivariate`: model is a multivariate response model (currently only works for _brmsfit_ and _vglm/vgam_ objects)
 #' * `is_trial`: model response contains additional information about the trials
 #' * `is_bayesian`: model is a Bayesian model
 #' * `is_gam`: model is a generalized additive model
 #' * `is_anova`: model is an Anova object
 #' * `is_ttest`: model is an an object of class `htest`, returned by `t.test()`
 #' * `is_correlation`: model is an an object of class `htest`, returned by `cor.test()`
-#' * `is_ranktest`: model is an an object of class `htest`, returned by `cor.test()` (if Spearman's rank correlation), `wilcox.text()` or `kruskal.test()`.
-#' * `is_variancetest`: model is an an object of class `htest`, returned by `bartlett.test()`, `shapiro.test()` or `car::leveneTest()`.
+#' * `is_ranktest`: model is an an object of class `htest`, returned by `cor.test()`
+#'   (if Spearman's rank correlation), `wilcox.text()` or `kruskal.test()`.
+#' * `is_variancetest`: model is an an object of class `htest`, returned by
+#'   `bartlett.test()`, `shapiro.test()` or `car::leveneTest()`.
 #' * `is_levenetest`: model is an an object of class `anova`, returned by `car::leveneTest()`.
 #' * `is_onewaytest`: model is an an object of class `htest`, returned by `oneway.test()`
 #' * `is_proptest`: model is an an object of class `htest`, returned by `prop.test()`
 #' * `is_binomtest`: model is an an object of class `htest`, returned by `binom.test()`
 #' * `is_chi2test`: model is an an object of class `htest`, returned by `chisq.test()`
-#' * `is_xtab`: model is an an object of class `htest` or `BFBayesFactor`, and test-statistic stems from a contingency table (i.e. `chisq.test()` or `BayesFactor::contingencyTableBF()`).
+#' * `is_xtab`: model is an an object of class `htest` or `BFBayesFactor`, and
+#'   test-statistic stems from a contingency table (i.e. `chisq.test()` or
+#'   `BayesFactor::contingencyTableBF()`).
 #' * `link_function`: the link-function
-#' * `family`: name of the distributional family of the model. For some exceptions (like some `htest` objects), can also be the name of the test.
+#' * `family`: name of the distributional family of the model. For some
+#'   exceptions (like some `htest` objects), can also be the name of the test.
 #' * `n_obs`: number of observations
 #' * `n_grouplevels`: for mixed models, returns names and numbers of random effect groups
 #'
@@ -66,19 +72,11 @@
 #' dat <- data.frame(ldose, sex, SF, stringsAsFactors = FALSE)
 #' m <- glm(SF ~ sex * ldose, family = binomial)
 #'
+#' # logistic regression
 #' model_info(m)
-#' \dontrun{
-#' library(glmmTMB)
-#' data("Salamanders")
-#' m <- glmmTMB(
-#'   count ~ spp + cover + mined + (1 | site),
-#'   ziformula = ~ spp + mined,
-#'   dispformula = ~DOY,
-#'   data = Salamanders,
-#'   family = nbinom2
-#' )
-#' }
 #'
+#' # t-test
+#' m <- t.test(1:10, y = c(7:20))
 #' model_info(m)
 #' @export
 model_info <- function(x, ...) {
@@ -90,7 +88,7 @@ model_info <- function(x, ...) {
 
 #' @export
 model_info.data.frame <- function(x, ...) {
-  stop("A data frame is no valid object for this function.", call. = FALSE)
+  format_error("A data frame is no valid object for this function.")
 }
 
 
@@ -102,20 +100,20 @@ model_info.default <- function(x, verbose = TRUE, ...) {
     class(x) <- c(class(x), c("glm", "lm"))
   }
 
-  faminfo <- tryCatch(
-    {
-      if (inherits(x, "Zelig-relogit")) {
-        stats::binomial(link = "logit")
-      } else {
-        stats::family(x)
-      }
-    },
-    error = function(x) {
-      NULL
+  faminfo <- .safe({
+    if (inherits(x, "Zelig-relogit")) {
+      stats::binomial(link = "logit")
+    } else {
+      stats::family(x)
     }
-  )
+  })
 
-  if (!is.null(faminfo)) {
+  if (is.null(faminfo)) {
+    if (isTRUE(verbose)) {
+      format_warning("Could not access model information.")
+    }
+    NULL
+  } else {
     .make_family(
       x = x,
       fitfam = faminfo$family,
@@ -124,11 +122,6 @@ model_info.default <- function(x, verbose = TRUE, ...) {
       verbose = verbose,
       ...
     )
-  } else {
-    if (isTRUE(verbose)) {
-      warning("Could not access model information.", call. = FALSE)
-    }
-    NULL
   }
 }
 
@@ -176,7 +169,19 @@ model_info.logitr <- model_info.mclogit
 
 #' @export
 model_info.maxLik <- function(x, verbose = TRUE, ...) {
-  .make_family(x, verbose = verbose, ...)
+  fitfam <- .safe(eval(get_call(x)$family))
+  if (is.null(fitfam)) {
+    .make_family(x, verbose = verbose, ...)
+  } else {
+    .make_family(
+      x,
+      fitfam = fitfam$family,
+      logit.link = fitfam$link == "logit",
+      link.fun = fitfam$link,
+      verbose = verbose,
+      ...
+    )
+  }
 }
 
 #' @export
@@ -200,6 +205,9 @@ model_info.bayesx <- model_info.maxLik
 #' @export
 model_info.rq <- model_info.maxLik
 
+#' @export
+model_info.rqs <- model_info.maxLik
+
 #' @export
 model_info.crq <- model_info.maxLik
 
@@ -302,18 +310,20 @@ model_info.mlm <- function(x, ...) {
   .make_family(x, multi.var = TRUE, ...)
 }
 
+
 #' @export
 model_info.afex_aov <- function(x, verbose = TRUE, ...) {
-  if (!is.null(x$aov)) {
-    .make_family(x$aov, verbose = verbose, ...)
-  } else {
+  if (is.null(x$aov)) {
     .make_family(x$lm, verbose = verbose, ...)
+  } else {
+    .make_family(x$aov, verbose = verbose, ...)
   }
 }
 
 
 # Models with logit-link --------------------------------
 
+
 #' @export
 model_info.logistf <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::binomial(link = "logit")
@@ -350,6 +360,33 @@ model_info.gmnl <- model_info.logistf
 
 
 
+# Phylo logit and poisson family ------------------------------------
+
+#' @export
+model_info.phylolm <- function(x, verbose = TRUE, ...) {
+  .make_family(x, verbose = verbose, ...)
+}
+
+
+#' @export
+model_info.phyloglm <- function(x, verbose = TRUE, ...) {
+  if (startsWith(x$method, "logistic")) {
+    faminfo <- stats::binomial(link = "logit")
+  } else {
+    faminfo <- stats::poisson()
+  }
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    verbose = verbose,
+    ...
+  )
+}
+
+
+
 # Models with ordinal family ------------------------------------
 
 
@@ -375,6 +412,7 @@ model_info.clmm <- model_info.clm
 #' @export
 model_info.mixor <- model_info.clm
 
+
 #' @export
 model_info.mvord <- function(x, verbose = verbose, ...) {
   link_name <- x$rho$link$name
@@ -391,9 +429,9 @@ model_info.mvord <- function(x, verbose = verbose, ...) {
 }
 
 
-
 # Models with family-function  ----------------------------------
 
+
 #' @export
 model_info.bamlss <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::family(x)
@@ -425,13 +463,13 @@ model_info.speedglm <- function(x, verbose = TRUE, ...) {
 model_info.brmultinom <- model_info.speedglm
 
 
-
 # Models with tobit family ----------------------------------
 
+
 #' @export
 model_info.flexsurvreg <- function(x, verbose = TRUE, ...) {
-  dist <- parse(text = safe_deparse(x$call))[[1]]$dist
-  faminfo <- .make_tobit_family(x, dist)
+  distribution <- parse(text = safe_deparse(x$call))[[1]]$dist
+  faminfo <- .make_tobit_family(x, distribution)
 
   .make_family(
     x = x,
@@ -521,16 +559,16 @@ model_info.fixest <- function(x, verbose = TRUE, ...) {
     )
   } else {
     fitfam <- switch(faminfo,
-      "negbin" = "negative binomial",
-      "logit" = "binomial",
+      negbin = "negative binomial",
+      logit = "binomial",
       faminfo
     )
 
     link <- switch(faminfo,
-      "poisson" = ,
-      "negbin" = "log",
-      "logit" = "logit",
-      "gaussian" = "identity"
+      poisson = ,
+      negbin = "log",
+      logit = "logit",
+      gaussian = "identity"
     )
 
     .make_family(
@@ -587,11 +625,11 @@ model_info.comprisk <- model_info.coxph
 #' @export
 model_info.zeroinfl <- function(x, ...) {
   if (is.list(x$dist)) {
-    dist <- x$dist[[1]]
+    distribution <- x$dist[[1]]
   } else {
-    dist <- x$dist
+    distribution <- x$dist
   }
-  fitfam <- switch(dist,
+  fitfam <- switch(distribution,
     poisson = "poisson",
     negbin = "negative binomial",
     "poisson"
@@ -612,11 +650,11 @@ model_info.zerotrunc <- model_info.zeroinfl
 #' @export
 model_info.hurdle <- function(x, ...) {
   if (is.list(x$dist)) {
-    dist <- x$dist[[1]]
+    distribution <- x$dist[[1]]
   } else {
-    dist <- x$dist
+    distribution <- x$dist
   }
-  fitfam <- switch(dist,
+  fitfam <- switch(distribution,
     poisson = "poisson",
     negbin = "negative binomial",
     "poisson"
@@ -706,19 +744,19 @@ model_info.stanmvreg <- function(x, ...) {
 #' @export
 model_info.BGGM <- function(x, ...) {
   link <- switch(x$type,
-    "continuous" = stats::gaussian(),
+    continuous = stats::gaussian(),
     stats::binomial()
   )
 
-  family <- switch(x$type,
-    "continuous" = "gaussian",
-    "binary" = "binomial",
+  fam <- switch(x$type,
+    continuous = "gaussian",
+    binary = "binomial",
     "ordinal"
   )
 
   .make_family(
     x = x,
-    fitfam = family,
+    fitfam = fam,
     zero.inf = FALSE,
     logit.link = link$link == "logit",
     link.fun = link$link,
@@ -777,9 +815,9 @@ model_info.coeftest <- function(x, ...) {
 #' @export
 model_info.glmm <- function(x, ...) {
   f <- switch(tolower(x$family.glmm$family.glmm),
-    "bernoulli.glmm" = ,
-    "binomial.glmm" = stats::binomial("logit"),
-    "poisson.glmm" = stats::poisson("log"),
+    bernoulli.glmm = ,
+    binomial.glmm = stats::binomial("logit"),
+    poisson.glmm = stats::poisson("log"),
     stats::gaussian("identity")
   )
   .make_family(
@@ -829,7 +867,7 @@ model_info.summary.lm <- model_info.Arima
 #' @export
 model_info.averaging <- function(x, ...) {
   if (is.null(attributes(x)$modelList)) {
-    warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.", call. = FALSE)
+    format_warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.")
     return(NULL)
   }
   model_info.default(x = attributes(x)$modelList[[1]])
@@ -849,15 +887,15 @@ model_info.cglm <- function(x, ...) {
 
   if (!is.null(method) && method == "clm") {
     .make_family(x, ...)
-  } else if (!is.null(link)) {
+  } else if (is.null(link)) {
+    .make_family(x, ...)
+  } else {
     .make_family(
       x,
       logit.link = link == "logit",
       link.fun = link,
       ...
     )
-  } else {
-    .make_family(x, ...)
   }
 }
 
@@ -899,14 +937,14 @@ model_info.LORgee <- function(x, ...) {
   }
 
   if (x$link == "Cumulative logit") {
-    family <- "ordinal"
+    fam <- "ordinal"
   } else {
-    family <- "multinomial"
+    fam <- "multinomial"
   }
 
   .make_family(
     x = x,
-    fitfam = family,
+    fitfam = fam,
     logit.link = link == "logit",
     link.fun = link,
     ...
@@ -914,7 +952,6 @@ model_info.LORgee <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.BBreg <- function(x, ...) {
   .make_family(
@@ -932,7 +969,6 @@ model_info.BBreg <- function(x, ...) {
 model_info.BBmm <- model_info.BBreg
 
 
-
 #' @export
 model_info.mmrm <- function(x, ...) {
   .make_family(
@@ -977,6 +1013,7 @@ model_info.cpglmm <- function(x, ...) {
   )
 }
 
+
 #' @export
 model_info.zcpglm <- function(x, ...) {
   link <- parse(text = safe_deparse(x@call))[[1]]$link
@@ -1018,7 +1055,6 @@ model_info.glimML <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.gam <- function(x, ...) {
   if (!inherits(x, c("glm", "lm"))) {
@@ -1026,11 +1062,12 @@ model_info.gam <- function(x, ...) {
   }
 
   faminfo <- .gam_family(x)
-
   link <- faminfo$link[1]
   is.mv <- faminfo$family == "Multivariate normal"
 
-  if (is.mv) link <- "identity"
+  if (is.mv) {
+    link <- "identity"
+  }
 
   .make_family(
     x = x,
@@ -1043,17 +1080,19 @@ model_info.gam <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.vgam <- function(x, ...) {
   faminfo <- x@family
   link.fun <- faminfo@blurb[3]
-  if (grepl("^(l|L)ogit", link.fun)) link.fun <- "logit"
+  if (grepl("^(l|L)ogit", link.fun)) {
+    link.fun <- "logit"
+  }
   .make_family(
     x = x,
     fitfam = faminfo@vfamily[1],
     logit.link = any(.string_contains("logit", faminfo@blurb)),
     link.fun = link.fun,
+    multi.var = is_multivariate(x),
     ...
   )
 }
@@ -1074,7 +1113,7 @@ model_info.glmmTMB <- function(x, ...) {
   check_if_installed("lme4")
 
   faminfo <- stats::family(x)
-  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi)
+  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi) || startsWith(faminfo$family, "truncated")
 
   .make_family(
     x = x,
@@ -1090,7 +1129,6 @@ model_info.glmmTMB <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.betareg <- function(x, ...) {
   .make_family(
@@ -1103,7 +1141,6 @@ model_info.betareg <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.DirichletRegModel <- function(x, ...) {
   .make_family(
@@ -1116,7 +1153,6 @@ model_info.DirichletRegModel <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.gbm <- function(x, ...) {
   faminfo <- switch(x$distribution$name,
@@ -1140,7 +1176,6 @@ model_info.gbm <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.MCMCglmm <- function(x, ...) {
   .make_family(
@@ -1153,7 +1188,6 @@ model_info.MCMCglmm <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.polr <- function(x, ...) {
   link <- x$method
@@ -1169,6 +1203,39 @@ model_info.polr <- function(x, ...) {
 }
 
 
+#' @export
+model_info.nestedLogit <- function(x, ...) {
+  faminfo <- stats::binomial(link = "logit")
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = TRUE,
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
+#' @export
+model_info.hglm <- function(x, ...) {
+  faminfo <- .safe({
+    mc <- get_call(x)$family
+    eval(mc)
+  })
+
+  if (is.null(faminfo)) {
+    return(NULL)
+  }
+
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
 
 #' @export
 model_info.orm <- function(x, ...) {
@@ -1183,7 +1250,6 @@ model_info.orm <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.svyolr <- function(x, ...) {
   l <- switch(x$method,
@@ -1201,13 +1267,20 @@ model_info.svyolr <- function(x, ...) {
 }
 
 
-
 #' @export
 model_info.gamlss <- function(x, ...) {
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
+  # for ZIBNB family, we have only one value, so next line returns NA
+  fitfam <- faminfo$family[2]
+  if (is.na(fitfam)) {
+    fitfam <- faminfo$family
+    if (is.null(fitfam)) {
+      fitfam <- "unknown"
+    }
+  }
   .make_family(
     x = x,
-    fitfam = faminfo$family[2],
+    fitfam = fitfam,
     logit.link = faminfo$mu.link == "logit",
     link.fun = faminfo$mu.link,
     ...
@@ -1217,15 +1290,10 @@ model_info.gamlss <- function(x, ...) {
 
 #' @export
 model_info.mipo <- function(x, verbose = TRUE, ...) {
-  tryCatch(
-    {
-      models <- eval(x$call$object)
-      model_info(models$analyses[[1]], verbose = verbose, ...)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  .safe({
+    models <- eval(x$call$object)
+    model_info(models$analyses[[1]], verbose = verbose, ...)
+  })
 }
 
 
@@ -1302,3 +1370,8 @@ model_info.earth <- function(x, ...) {
 model_info.deltaMethod <- function(x, ...) {
   NULL
 }
+
+#' @export
+model_info.ggcomparisons <- function(x, ...) {
+  NULL
+}
