@@ -23,16 +23,16 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' n_obs(m)
 #'
-#' if (require("lme4")) {
-#'   data(cbpp, package = "lme4")
-#'   m <- glm(
-#'     cbind(incidence, size - incidence) ~ period,
-#'     data = cbpp,
-#'     family = binomial(link = "logit")
-#'   )
-#'   n_obs(m)
-#'   n_obs(m, disaggregate = TRUE)
-#' }
+#' @examplesIf require("lme4", quietly = TRUE)
+#' data(cbpp, package = "lme4")
+#' m <- glm(
+#'   cbind(incidence, size - incidence) ~ period,
+#'   data = cbpp,
+#'   family = binomial(link = "logit")
+#' )
+#' n_obs(m)
+#' n_obs(m, disaggregate = TRUE)
+#'
 #' @export
 n_obs <- function(x, ...) {
   UseMethod("n_obs")
@@ -88,9 +88,10 @@ n_obs.glm <- function(x, disaggregate = FALSE, ...) {
       }
 
       # response is a fraction
-    } else if (!is.data.frame(resp_data) && .is.fraction(resp_data)) {
+    } else if (!is.data.frame(resp_data) && .is_fraction(resp_data)) {
       .nobs <- sum(get_weights(x))
     }
+    .nobs <- as.integer(.nobs)
   }
 
   .nobs
@@ -99,11 +100,13 @@ n_obs.glm <- function(x, disaggregate = FALSE, ...) {
 #' @export
 n_obs.censReg <- n_obs.default
 
+
 #' @export
 n_obs.nestedLogit <- function(x, disaggregate = FALSE, ...) {
   lapply(x$models, n_obs)
 }
 
+
 #' @rdname n_obs
 #' @export
 n_obs.svyolr <- function(x, weighted = FALSE, ...) {
@@ -120,7 +123,6 @@ n_obs.svy_vglm <- function(x, ...) {
   n_obs(x$fit)
 }
 
-
 #' @export
 n_obs.model_fit <- n_obs.svy_vglm
 
@@ -133,13 +135,14 @@ n_obs.HLfit <- function(x, ...) {
 
 #' @export
 n_obs.gam <- function(x, ...) {
-  if (!is.null(dim(x$y))) {
-    dim(x$y)[1]
-  } else {
+  if (is.null(dim(x$y))) {
     length(x$y)
+  } else {
+    dim(x$y)[1]
   }
 }
 
+
 #' @export
 n_obs.gamm <- function(x, ...) {
   if (object_has_names(x, "gam")) {
@@ -164,8 +167,8 @@ n_obs.selection <- function(x, type = c("all", "observed", "censored"), ...) {
   type <- match.arg(type)
   s <- summary(x)
   switch(type,
-    "all" = s$param$nObs,
-    "observed" = s$param$N1,
+    all = s$param$nObs,
+    observed = s$param$N1,
     s$param$N0
   )
 }
@@ -189,14 +192,12 @@ n_obs.merModList <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.summary.lm <- function(x, ...) {
   length(x$residuals)
 }
 
 
-
 #' @export
 n_obs.mediate <- function(x, ...) {
   x$nobs
@@ -215,63 +216,54 @@ n_obs.garch <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.bayesx <- function(x, ...) {
   length(x$response)
 }
 
 
-
 #' @export
 n_obs.flexsurvreg <- function(x, ...) {
   x$N
 }
 
 
-
 #' @export
 n_obs.SemiParBIV <- function(x, ...) {
   x$n
 }
 
 
-
 #' @export
 n_obs.ivprobit <- function(x, ...) {
   nrow(x$mr1)
 }
 
 
-
 #' @export
 n_obs.mvord <- function(x, ...) {
   x$rho$n
 }
 
 
-
 #' @export
 n_obs.bamlss <- function(x, ...) {
   nrow(x$model.frame)
 }
 
 
-
 #' @export
 n_obs.coeftest <- function(x, ...) {
   attributes(x)$nobs
 }
 
 
-
 #' @export
 n_obs.lmRob <- function(x, ...) {
   length(x$fitted.values)
 }
 
 
-
 #' @export
 n_obs.lqmm <- function(x, ...) {
   x$nobs
@@ -281,8 +273,6 @@ n_obs.lqmm <- function(x, ...) {
 n_obs.lqm <- n_obs.lqmm
 
 
-
-
 #' @export
 n_obs.sem <- function(x, ...) {
   if (!.is_semLme(x)) {
@@ -292,28 +282,24 @@ n_obs.sem <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.LORgee <- function(x, ...) {
   x$nobs
 }
 
 
-
 #' @export
 n_obs.crr <- function(x, ...) {
   x$n
 }
 
 
-
 #' @export
 n_obs.mcmc <- function(x, ...) {
   nrow(as.data.frame(x))
 }
 
 
-
 #' @export
 n_obs.biglm <- function(x, ...) {
   x$n
@@ -338,7 +324,10 @@ n_obs.zerotrunc <- n_obs.biglm
 n_obs.zeroinfl <- n_obs.biglm
 
 
-
+#' @export
+n_obs.rqs <- function(x, ...) {
+  length(x$y)
+}
 
 
 #' @export
@@ -350,7 +339,6 @@ n_obs.cgam <- function(x, ...) {
 n_obs.cglm <- n_obs.cgam
 
 
-
 #' @export
 n_obs.gbm <- function(x, ...) {
   length(x$fit)
@@ -381,7 +369,6 @@ n_obs.glimML <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.mle2 <- function(x, ...) {
   n <- .safe(x@nobs)
@@ -395,42 +382,36 @@ n_obs.mle2 <- function(x, ...) {
 n_obs.mle <- n_obs.mle2
 
 
-
 #' @export
 n_obs.glmRob <- function(x, ...) {
   length(x$fitted.values)
 }
 
 
-
 #' @export
 n_obs.gmnl <- function(x, ...) {
   x$logLik$nobs
 }
 
 
-
 #' @export
 n_obs.multinom <- function(x, ...) {
   nrow(x$fitted.values)
 }
 
 
-
 #' @export
 n_obs.cpglmm <- function(x, ...) {
   nrow(x@frame)
 }
 
 
-
 #' @export
 n_obs.lmodel2 <- function(x, ...) {
   nrow(get_data(x, verbose = FALSE))
 }
 
 
-
 #' @export
 n_obs.cpglm <- function(x, ...) {
   nrow(x$model.frame)
@@ -460,7 +441,6 @@ n_obs.BBreg <- function(x, ...) {
 n_obs.BBmm <- n_obs.BBreg
 
 
-
 #' @export
 n_obs.crq <- function(x, ...) {
   n <- nrow(x$residuals)
@@ -501,35 +481,30 @@ n_obs.MANOVA <- function(x, ...) {
 n_obs.RM <- n_obs.MANOVA
 
 
-
 #' @export
 n_obs.nlrq <- function(x, ...) {
   length(stats::fitted(x))
 }
 
 
-
 #' @export
 n_obs.survfit <- function(x, ...) {
   length(x$n.event)
 }
 
 
-
 #' @export
 n_obs.mhurdle <- function(x, ...) {
   nrow(x$model)
 }
 
 
-
 #' @export
 n_obs.survreg <- function(x, ...) {
   length(x$linear.predictors)
 }
 
 
-
 #' @export
 n_obs.aareg <- function(x, ...) {
   max(x$n)
@@ -555,28 +530,24 @@ n_obs.felm <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.feis <- function(x, ...) {
   length(x$fitted.values)
 }
 
 
-
 #' @export
 n_obs.averaging <- function(x, ...) {
   attr(x, "nobs")
 }
 
 
-
 #' @export
 n_obs.fixest <- function(x, ...) {
   x$nobs
 }
 
 
-
 #' @export
 n_obs.feglm <- function(x, ...) {
   x$nobs[["nobs"]]
@@ -595,7 +566,6 @@ n_obs.aovlist <- function(x, ...) {
 }
 
 
-
 #' @rdname n_obs
 #' @export
 n_obs.stanmvreg <- function(x, select = NULL, ...) {
@@ -620,7 +590,6 @@ n_obs.stanmvreg <- function(x, select = NULL, ...) {
 }
 
 
-
 #' @export
 n_obs.blrm <- function(x, ...) {
   x$N
@@ -632,11 +601,9 @@ n_obs.mlogit <- function(x, ...) {
   nrow(x$model)
 }
 
-
 #' @export
 n_obs.Glm <- n_obs.mlogit
 
-
 #' @export
 n_obs.maxLik <- n_obs.mlogit
 
@@ -647,7 +614,6 @@ n_obs.wbm <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.wbgee <- function(x, ...) {
   stats::nobs(x)
